@@ -1,26 +1,21 @@
 package Vimana;
+
 use warnings;
 use strict;
 use Vimana::Index;
-use vars qw($INDEX);
 
-our $VERSION = '2.26';
+use vars qw($INDEX $CACHE);
 
-sub index {
-    return $INDEX if $INDEX;
-    $INDEX ||= Vimana::Index->new;
-    $INDEX->init();
-    return $INDEX;
-}
-
-1;
-__END__
 =encoding utf8
 
 =head1 NAME
 
 Vimana - Vim script manager.
 
+=cut
+
+our $VERSION = 2009.33100 ;
+
 =head1 DESCRIPTION
 
 Vimana is an easy to use system for searching , installing, and downloading vim
@@ -31,41 +26,50 @@ Debian linux, for you to search , download , install , upgrade scripts from
 L<http://www.vim.org> (vimonline site).
 
 Vimana can install a vim script package to your vim runtime path automatically
-by inspecting the content of archive file or vim script. For example , if an
+by inspecting the content of archive file or vim script. for example , if an
 archive file contains 'syntax','plugin','indent' directory , then these files
-should be installed to F<~/.vim/> directory (default vim runtime directory).   
-if it's a vim color scheme , then it should be put into F<~/.vim/colors/>,
-or Vimana will inspect the script type tag in script file.
+should be installed to F<~/.vim/> directory.   if it's a vim color scheme ,
+then it should be put into F<~/.vim/colors/> and prompt for setting the
+installed colorscheme as default.
+
+We plan to provide port files via git repository, vimrc customization and
+internationalization in future.
+
+( In some modern Indian languages, vimāna or vimān means "aircraft". )
+
+NOTE: Vimana only provides search,info,install commmands currently.
 
 * Getting started from L<Vimana::Manual>.
 
-=head1 USAGE
-
-to update index
-
-    $ vimana update 
-
-check rails.vim plugin info
-
-    $ vimana info rails.vim
-
-to search scripts:
-
-    $ vimana s perl
-
-to install package:
-
-    $ vimana i autocomplpop.vim
-
-    # with verbose message
-    $ vimana i -v the-nerd-tree
-
-to remove a package:
-
-    $ vimana remove the-nerd-tree
-
 =head1 FUNCTIONS
 
+=head2 cache
+
+=cut
+
+sub cache {
+    return $CACHE if $CACHE;
+    my $cache = Cache::File->new(
+        cache_root      => $ENV{VIMANA_CACHE_DIR} || '/tmp/vim.get',
+        lock_level      => Cache::File::LOCK_LOCAL(),
+        default_expires => '3 hours'
+    );
+    return $CACHE = $cache;
+}
+
+=head2 index
+
+=cut
+
+sub index {
+    return $INDEX if $INDEX;
+    $INDEX ||= Vimana::Index->new;
+    $INDEX->init();
+    return $INDEX;
+}
+
+
+
 =head1 AUTHOR
 
 You-An Lin 林佑安 ( Cornelius / c9s ) C<< <cornelius.howl at gmail.com> >>
@@ -123,4 +127,7 @@ Copyright 2007 You-An Lin 林佑安 ( Cornelius / c9s ), all rights reserved.
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
 
+
 =cut
+
+1; # End of Vimana
