@@ -7,6 +7,8 @@ use Vimana::Logger;
 use base qw/Class::Accessor::Fast/;
 __PACKAGE__->mk_accessors( qw(package) );
 
+use DateTime;
+
 sub run {
     my $self = shift;
     $self->install_vimballs( $self->package->file );
@@ -19,6 +21,13 @@ sub install_vimballs {
     for my $vimball ( @files ) {
         $logger->info( "Installing Vimball: $vimball" );
         system( qq|$vim $vimball -c ":so %" -c q|);
+
+#        Vimana::Record->set(
+#            cname => $self->package->cname,
+#            type  => 'vimball',
+#            source => $vimball,
+#            install_date => DateTime->now,
+#        );
     }
 }
 
